simplify.constants

Package simplify :: Module constants |
[hide private]
[frames] | no frames]

# Source Code for Module simplify.constants

     1
     2  #
     3  # Copyright (c) 2013 - 2022 MasterCard International Incorporated
     4  # All rights reserved.
     5  #
     6  # Redistribution and use in source and binary forms, with or without modification, are
     7  # permitted provided that the following conditions are met:
     8  #
     9  # Redistributions of source code must retain the above copyright notice, this list of
    10  # conditions and the following disclaimer.
    11  # Redistributions in binary form must reproduce the above copyright notice, this list of
    12  # conditions and the following disclaimer in the documentation and/or other materials
    13  # provided with the distribution.
    14  # Neither the name of the MasterCard International Incorporated nor the names of its
    15  # contributors may be used to endorse or promote products derived from this software
    16  # without specific prior written permission.
    17  # THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
    18  # EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
    19  # OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
    20  # SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
    21  # INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
    22  # TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
    23  # OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
    24  # IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
    25  # IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
    26  # SUCH DAMAGE.
    27  #
    28
    29 -class Constants:
    30      """
    31          Holds constant values.
    32      """
    33
    34
    35      version = '1.8.0'
    36
    37      api_base_live_url = 'https://api.simplify.com/v1/api'
    38
    39      api_base_sandbox_url = 'https://sandbox.simplify.com/v1/api'
    40
    41      oauth_base_url = 'https://www.simplify.com/commerce/oauth'
    42